src/hg/js/hui.js 1.57

1.57 2010/05/27 16:41:47 tdreszer
Empty selection is invalid fro filterBy. Force it to 'All' when this case happens.
Index: src/hg/js/hui.js
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/js/hui.js,v
retrieving revision 1.56
retrieving revision 1.57
diff -b -B -U 4 -r1.56 -r1.57
--- src/hg/js/hui.js	24 May 2010 23:01:21 -0000	1.56
+++ src/hg/js/hui.js	27 May 2010 16:41:47 -0000	1.57
@@ -168,9 +168,9 @@
     return true;
 }
 
 function filterCompositeSelectionChanged(obj)
-{ // filterComposite:onchange Set subtrack selection based upon the changed filter
+{ // filterComposite:onchange Set subtrack selection based upon the changed filter  [Not called for filterBy]
 
     if($(obj).val() != undefined
     && $(obj).val().toString().indexOf("All,") != -1) {
         $(obj).val("All");
@@ -1183,6 +1183,8 @@
         );
     }
     $('.halfVis').css('opacity', '0.5'); // The 1/2 opacity just doesn't get set from cgi!
 
-    $('.filterComp').dropdownchecklist({ firstItemChecksAll: true, emptyText: 'Please select ...' });
+    $('.filterComp').each( function(i) { // Do this by 'each' to set noneIsAll individually
+        $(this).dropdownchecklist({ firstItemChecksAll: true, noneIsAll: $(this).hasClass('filterBy') });
+    });
 });